==> flyspray_0.9.6a.orig.tar.gz: flyspray-0.9.6/lang/de/admin.php <==
﻿<?php

global $admin_text;
$admin_text = array (

'edituser'          =>  'Benutzer bearbeiten',
'username'          =>  'Benutzername',
'realname'          =>  'Realname',
'emailaddress'      =>  'E-Mail Adresse',
'jabberid'          =>  'Jabber ID',
'notifytype'        =>  'Benachrichtigungstyp',
'group'             =>  'Gruppe',
'accountenabled'    =>  'Konto aktiviert',
'updatedetails'     =>  'Details updaten',
'setglobally'       =>  'Diese Einstellung ist global gesetzt.',

'usergroupmanage'   =>  'Benutzer- und Gruppenmanagement',
'newuser'           =>  'Neuen Benutzer registrieren',
'newgroup'          =>  'Neue Gruppe erstellen',
'yes'               =>  'Ja',
'no'                =>  'Nein',

'editgroup'         =>  'Gruppe bearbeiten',
'groupname'         =>  'Gruppenname',
'description'       =>  'Beschreibung',
'admin'             =>  'Administratorgruppe',
'opennewtasks'      =>  'Neue Aufgaben öffnen',
'modifytasks'       =>  'Existierende Aufgaben ändern',
'addcomments'       =>  'Kommentare hinzufügen',
'attachfiles'       =>  'Dateien anhängen',
'vote'              =>  'Abstimmen',
'groupenabled'      =>  'Mitglieder können sich einloggen (Gruppe aktiv)',

'tasktypelist'      =>  'Liste: Aufgabentypen',
'categorylist'      =>  'Liste: Kategorien',
'oslist'            =>  'Liste: Betriebssysteme',
'resolutionlist'    =>  'Liste: Erledigungsstatus',
'versionlist'       =>  'Liste: Versionen',
'severitylist'      =>  'Liste: Schweregrade',
'listnote'          =>  'Anmerkung: Wenn Sie das "Anzeigen"-Kästchen abwählen, können einige Aufgaben beim Bearbeiten anders dargestellt werden. Ändern Sie das Feld "Name", erhalten alle Aufgaben diesen neuen Namen.',
'name'              =>  'Name',
'order'             =>  'Reihenfolge',
'back'              =>  'Zurück',
'text'              =>  'Text',
'highlight'         =>  'Hervorheben',
'show'              =>  'Anzeigen',
'owner'             =>  'Inhaber',
'selectowner'       =>  'Inhaber auswählen',
'update'            =>  'Aktualisieren',
'addnew'            =>  'Hinzufügen',

'flysprayprefs'     =>  'Flyspray Optionen',
'projecttitle'      =>  'Projekttitel',
'baseurl'           =>  'Basis-URL für diese Installation',
'replyaddress'      =>  'Antwortadresse für E-Mail-Benachrichtigungen',
'themestyle'        =>  'Design',
'language'          =>  'Sprache',
'anonview'          =>  'Anonymen Benutzern erlauben, Aufgaben einzusehen',
'allowanon'         =>  'Anonymen Benutzern das Öffnen neuer Aufgaben erlauben',
'never'             =>  'Niemals',
'anonymously'       =>  'Anonym',
'afterregister'     =>  'Nach Registrierung',
'spamproof'         =>  'Bestätigungscode für das Registrieren neuer Benutzer aktivieren',
'anongroup'         =>  'Gruppe für anonyme Registrierungen',
'groupassigned'     =>  'Mitglieder dieser Gruppen können Aufgaben zugeteilt werden',
'forcenotify'       =>  'Benachrichtigung zwingend als',
'none'              =>  'Niemals senden',
'userchoose'        =>  'Jeden Benutzer wählen lassen',
'email'             =>  'E-Mail',
'jabber'            =>  'Jabber',
'defaultcatowner'   =>  'Standard Kategorie-Inhaber',
'noone'             =>  'Niemand',
'jabbernotify'      =>  'Jabber Benachrichtigungen',
'jabberserver'      =>  'Server',
'jabberport'        =>  'Port',
'jabberuser'        =>  'Account Benutzername',
'jabberpass'        =>  'Account Passwort',
'saveoptions'       =>  'Optionen speichern',

'editcomment'       =>  'Kommentar bearbeiten',
'commentby'         =>  'Kommentar von',
'saveeditedcomment' =>  'Bearbeiteten Kommentar speichern',

// Added in version 0.9.5

'projectprefs'      =>  'Projekteinstellungen',
'defaultproject'    =>  'Standardprojekt',
'projectlists'      =>  'Projektlisten',
'showlogo'          =>  'Titellogo anzeigen',
'intromessage'      =>  'Begrüßungsnachricht',
'isactive'          =>  'Projekt ist aktiv',
'createproject'     =>  'Neues Projekt erstellen',

// Added in version 0.9.6

'nopermission'      =>  'Sie haben keine Berechtigung, diese Seite zu verwenden.',
'listordertip'      =>  'Die Reihenfolge, in der diese Einträge in der Liste erscheinen',
'listshowtip'       =>  'Diesen Eintrag in der Liste anzeigen',
'categoryownertip'  =>  'Dieser Benutzer erhält eine Benachrichtigung, wenn eine Aufgabe in dieser Kategorie geöffnet wird',
'categoryparenttip' =>  'Die übergeordnete Kategorie, unter die die neue fallen soll',
'notsubcategory'    =>  'Keine - neue Kategorie oberster Ebene',
'showinlineimages'  =>  'Angehängte Bilder als Vorschau anzeigen',
'dateformat'        =>  'Datumsformat',
'dateformat_extended' =>'Erweitertes Datumsformat',
'subcategoryof'     =>  'Unterkategorie von',
'visiblecolumns'    =>  'Spalten in der Aufgabenliste',
'tense'             =>  'Zeitliche Einordnung',
'listtensetip'      =>  'Vergangenheit, Gegenwart oder Zukunft',
'past'              =>  'Vergangenheit',
'present'           =>  'Gegenwart',
'future'            =>  'Zukunft',
'changepass'        =>  'Passwort ändern',
'confirmpass'       =>  'Passwort bestätigen',

);
?>

==> flyspray_0.9.7.orig.tar.gz: flyspray-0.9.7/lang/de/admin.php <==
<?php

global $admin_text;
$admin_text = array (

'edituser'          =>  'Benutzer bearbeiten',
'username'          =>  'Benutzername',
'realname'          =>  'Realname',
'emailaddress'      =>  'E-Mail Adresse',
'jabberid'          =>  'Jabber ID',
'notifytype'        =>  'Benachrichtigungstyp',
'group'             =>  'Gruppe',
'accountenabled'    =>  'Konto aktiviert',
'updatedetails'     =>  'Details updaten',
'setglobally'       =>  'Diese Einstellung ist global gesetzt.',

'usergroupmanage'   =>  'Benutzer- und Gruppenmanagement',
'newuser'           =>  'Neuen Benutzer registrieren',
'newgroup'          =>  'Neue Gruppe erstellen',
'yes'               =>  'Ja',
'no'                =>  'Nein',

'editgroup'         =>  'Gruppe bearbeiten',
'groupname'         =>  'Gruppenname',
'description'       =>  'Beschreibung',
'admin'             =>  'Administratorgruppe',
'opennewtasks'      =>  'Neue Aufgaben öffnen',
'modifytasks'       =>  'Existierende Aufgaben ändern',
'addcomments'       =>  'Kommentare hinzufügen',
'attachfiles'       =>  'Dateien anhängen',
'vote'              =>  'Abstimmen',
'groupenabled'      =>  'Mitglieder können sich einloggen (Gruppe aktiv)',

'tasktypelist'      =>  'Liste: Aufgabentypen',
'categorylist'      =>  'Liste: Kategorien',
'oslist'            =>  'Liste: Betriebssysteme',
'resolutionlist'    =>  'Liste: Erledigungsstatus',
'versionlist'       =>  'Liste: Versionen',
'severitylist'      =>  'Liste: Schweregrade',
'listnote'          =>  'Anmerkung: Wenn Sie das "Anzeigen"-Kästchen abwählen, können einige Aufgaben beim Bearbeiten anders dargestellt werden. Ändern Sie das Feld "Name", erhalten alle Aufgaben diesen neuen Namen.',
'name'              =>  'Name',
'order'             =>  'Reihenfolge',
'back'              =>  'Zurück',
'text'              =>  'Text',
'highlight'         =>  'Hervorheben',
'show'              =>  'Anzeigen',
'owner'             =>  'Inhaber',
'selectowner'       =>  'Inhaber auswählen',
'update'            =>  'Aktualisieren',
'addnew'            =>  'Hinzufügen',

'flysprayprefs'     =>  'Flyspray Optionen',
'projecttitle'      =>  'Projekttitel',
'baseurl'           =>  'Basis-URL für diese Installation',
'replyaddress'      =>  'Antwortadresse für E-Mail-Benachrichtigungen',
'themestyle'        =>  'Design',
'language'          =>  'Sprache',
'anonview'          =>  'Anonymen Benutzern erlauben, Aufgaben einzusehen',
'allowanon'         =>  'Anonymen Benutzern das Öffnen neuer Aufgaben erlauben',
'never'             =>  'Niemals',
'anonymously'       =>  'Anonym',
'afterregister'     =>  'Nach Registrierung',
'spamproof'         =>  'Bestätigungscode für das Registrieren neuer Benutzer aktivieren',
'anongroup'         =>  'Gruppe für anonyme Registrierungen',
'groupassigned'     =>  'Mitglieder dieser Gruppen können Aufgaben zugeteilt werden',
'forcenotify'       =>  'Benachrichtigung zwingend als',
'none'              =>  'Niemals senden',
'userchoose'        =>  'Jeden Benutzer wählen lassen',
'email'             =>  'E-Mail',
'jabber'            =>  'Jabber',
'defaultcatowner'   =>  'Standard Kategorie-Inhaber',
'noone'             =>  'Niemand',
'jabbernotify'      =>  'Jabber Benachrichtigungen',
'jabberserver'      =>  'Server',
'jabberport'        =>  'Port',
'jabberuser'        =>  'Account Benutzername',
'jabberpass'        =>  'Account Passwort',
'saveoptions'       =>  'Optionen speichern',

'editcomment'       =>  'Kommentar bearbeiten',
'commentby'         =>  'Kommentar von',
'saveeditedcomment' =>  'Bearbeiteten Kommentar speichern',

// Added in version 0.9.5

'projectprefs'      =>  'Projekteinstellungen',
'defaultproject'    =>  'Standardprojekt',
'projectlists'      =>  'Projektlisten',
'showlogo'          =>  'Titellogo anzeigen',
'intromessage'      =>  'Begrüßungsnachricht',
'isactive'          =>  'Projekt ist aktiv',
'createproject'     =>  'Neues Projekt erstellen',

// Added in version 0.9.6

'nopermission'      =>  'Sie haben keine Berechtigung, diese Seite zu verwenden.',
'listordertip'      =>  'Die Reihenfolge, in der diese Einträge in der Liste erscheinen',
'listshowtip'       =>  'Diesen Eintrag in der Liste anzeigen',
'categoryownertip'  =>  'Dieser Benutzer erhält eine Benachrichtigung, wenn eine Aufgabe in dieser Kategorie geöffnet wird',
'categoryparenttip' =>  'Die übergeordnete Kategorie, unter die die neue fallen soll',
'notsubcategory'    =>  'Keine - neue Kategorie oberster Ebene',
'showinlineimages'  =>  'Angehängte Bilder als Vorschau anzeigen',
'dateformat'        =>  'Datumsformat',
'dateformat_extended' =>'Erweitertes Datumsformat',
'subcategoryof'     =>  'Unterkategorie von',
'visiblecolumns'    =>  'Spalten in der Aufgabenliste',
'tense'             =>  'Zeitliche Einordnung',
'listtensetip'      =>  'Vergangenheit, Gegenwart oder Zukunft',
'past'              =>  'Vergangenheit',
'present'           =>  'Gegenwart',
'future'            =>  'Zukunft',
'changepass'        =>  'Passwort ändern',
'confirmpass'       =>  'Passwort bestätigen',

// Added in version 0.9.7
'projectmanager'    =>  'Projektmanager',
'viewtasks'         =>  'Aufgaben anzeigen',
'opennewtasks'      =>  'Neue Aufgaben anlegen',
'modifyowntasks'    =>  'Eigene Aufgaben bearbeiten',
'modifyalltasks'    =>  'Aufgaben bearbeiten, die jemand anderem zugeteilt sind',
'viewcomments'      =>  'Kommentare anzeigen',
'editcomments'      =>  'Kommentare bearbeiten',
'deletecomments'    =>  'Kommentare löschen',
'viewattachments'   =>  'Anhänge anzeigen',
'createattachments' =>  'Anhänge erstellen',
'deleteattachments' =>  'Anhänge löschen',
'viewhistory'       =>  'Historie anzeigen',
'closeowntasks'     =>  'Eigene Aufgaben schließen',
'closeothertasks'   =>  'Aufgaben schließen, die jemand anderem zugeteilt sind',
'assigntoself'      =>  'Sich noch nicht zugeteilte Aufgaben selbst zuweisen',
'assignotherstoself'=>  'Sich jemand anderem zugeteilte Aufgaben selbst zuweisen',
'viewreports'       =>  'Berichte anzeigen',
'othersview'        =>  'Jeder darf die Aufgaben dieses Projektes anzeigen',
'usergroups'        =>  'Benutzer und Gruppen',
'globalgroup'       =>  'Globale Gruppe',
'globalgroups'      =>  'Globale Gruppen',
'defaultglobalgroup'=>  'Standardgruppe für neue Benutzer',
'addtogroup'        =>  'Zur Gruppe hinzufügen',
'moveuserstogroup'  =>  'In Gruppe verschieben',
'nogroup'           =>  'Keine Gruppe - aus Projekt entfernen',
'pendingrequests'   =>  'Anliegende Administrationsaufgaben',
'eventdesc'         =>  'Ereignisbeschreibung',
'requestedby'       =>  'Angefordert von',
'daterequested'     =>  'Datum der Anforderung',
'closetask'         =>  'Aufgabe schließen',
'reopentask'        =>  'Aufgabe wiedereröffnen',
'applymember'       =>  'Bitte um Projektmitgliedschaft',
'forcurrentproj'    =>  'Für das aktuelle Projekt',
'lostpw'            =>  'Passwort verloren',
'lostpwexplain'     =>  'Geben Sie Ihren Benutzernamen ein, um einen Link zum Ändern Ihres Passwortes an die in Ihrem Profil eingestellte Benachrichtigungsadresse zu erhalten.',
'sendlink'          =>  'Link senden',
'savenewpass'       =>  'Neues Passwort speichern',
'badmagic'          =>  'Der Bestätigungscode ist ungültig. Stellen Sie sicher, dass Sie den Code richtig aus der Benachrichtigung kopiert haben.',
'anonreg'           =>  'Neue Benutzerregistrierungen zulassen',
'allowanonopentask' =>  'Gäste dürfen neue Aufgaben anlegen',
'editglobalgroup'   =>  'Globale Gruppe bearbeiten',
'editgroupforproj'  =>  'Gruppe für dieses Projekt bearbeiten',
'notshownforadmin'  =>  'Die Berechtigungen der Administratorgruppe können nicht geändert werden.',
'general'           =>  'Allgemein',
'userregistration'  =>  'Benutzerregistrierung',
'notifications'     =>  'Benachrichtigungen',
'resetoptions'      =>  'Einstellungen zurücksetzen',

);
?>
